@@ -5,7 +5,7 @@ Created on Sun Nov  7 11:58:46 2021
 @author: kentang
 """
 
-from config import *
+from kintaiyi.config import *
 import sxtwl, re, math, itertools, datetime
 import numpy as np
 
